﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Ecng.Common;
using StockSharp.Logging;
using StockSharp.Xaml;

namespace WpfApp2
{
    /// <summary>
    /// Логика взаимодействия для MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window, ILogSource
    {
        public TestSourceWindow TestSourceWindow;
        private readonly LogManager _logManager = new LogManager();
        public Guid Id { get; }
        public ILogSource Parent { get; set; }
        public LogLevels LogLevel { get; set; }
        public DateTimeOffset CurrentTime => DateTimeOffset.Now;
        public bool IsRoot { get; }
        public MonitorWindow MonitorWindow { get; private set; }

        public event Action<LogMessage> Log;

        public MainWindow()
        {
            InitializeComponent();
            this.LogLevel = LogLevels.Verbose;
            _logManager = new LogManager();
            _logManager.Sources.Add(this);

            TestSourceWindow = new TestSourceWindow();
            TestSourceWindow.Parent = this;
            TestSourceWindow.LogLevel = LogLevel;
            _logManager.Sources.Add(TestSourceWindow);

            MonitorWindow = new MonitorWindow();
            _logManager.Listeners.Add(MonitorWindow);
            MonitorWindow.Show();

            Loaded += MainWindow_Loaded;
        }

        /// <summary>
        /// Выводим 10 сообщений главного окна
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void MainWindow_Loaded(object sender, RoutedEventArgs e)
        {
            for (var i = 0; i < 10; i++)
            {
                var level = RandomGen.GetEnum<LogLevels>();

                switch (level)
                {
                    case LogLevels.Verbose:
                    case LogLevels.Inherit:
                    case LogLevels.Debug:
                    case LogLevels.Info:
                    case LogLevels.Off:
                        Log?.Invoke(new LogMessage(this, CurrentTime, LogLevel, $"Сообщение главного окна {level}"));
                        break;
                    case LogLevels.Warning:
                        Log?.Invoke(new LogMessage(this, CurrentTime, LogLevel, $"Сообщение главного окна {level}"));
                        break;
                    case LogLevels.Error:
                        Log?.Invoke(new LogMessage(this, CurrentTime, LogLevel, $"Сообщение главного окна {level}"));
                        break;
                    default:
                        throw new ArgumentOutOfRangeException();
                }

            }
        }

        private void Button_Click(object sender, RoutedEventArgs e)
        {
            TestSourceWindow.Show();
        }

        public void Dispose()
        {
            throw new NotImplementedException();
        }

    }
}
